#include <msp430.h>
#include <spi.h>
#include <DAC81416.h>
#include <stdint.h>

#ifndef SPI_POLLING
extern uint8_t rx_buffer[SPI_MAX_BUFF_SIZE];
#endif

void DAC81416_init(void)
{
   spi_init();
   DAC81416_write_register(SPICONFIG, SDO_EN);
}

void DAC81416_write_register(uint8_t reg_to_write, uint16_t config)
{
#ifdef SPI_POLLING
    uint8_t send[3];
    send[0] = reg_to_write;
    send[1] = (config >> 8);
    send[2] = config & 0xff;
    spi_write_bytes(send, 0x03);
#else
    DAC81416_data_t command;
    command.data = config;
    spi_write(reg_to_write, command.data_serial, 0x02);
#endif
}

uint16_t DAC81416_read_register(uint8_t reg_to_read)
{
    uint8_t rtr = READ_BIT | reg_to_read;
#ifdef SPI_POLLING
    uint8_t arr_in[3] = {rtr, DUMMY, DUMMY};
    uint8_t arr_out[3];
    spi_write_bytes(arr_in, 0x03);
    __delay_cycles(5);
    spi_read_bytes(arr_out, 0x03);
    uint16_t o = (arr_out[2] << 8) | arr_out[1];
    return o;
#else
    spi_read(rtr, 0x03);
    return (rx_buffer[0] | (rx_buffer[1] << 8));
#endif


}

//read out registers
uint16_t DAC81416_get_device_id(void)
{
    return DAC81416_read_register(DEVICEID);
}

uint16_t DAC81416_get_status(void)
{
    return DAC81416_read_register(STATUS);
}

uint16_t DAC81416_get_dac_data(uint8_t dac)
{
    return DAC81416_read_register(dac) & 0xFFFF;
}
